@@ -192,7 +192,26 @@ class ApiGatewayToSqs(
         :summary: Constructs a new instance of the ApiGatewayToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSqs.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Any = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSqsProps(
@@ -305,7 +324,24 @@ class ApiGatewayToSqsProps:
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToSqsProps.__init__)
+            def stub(
+                *,
+                allow_create_operation: typing.Optional[builtins.bool] = None,
+                allow_delete_operation: typing.Optional[builtins.bool] = None,
+                allow_read_operation: typing.Optional[builtins.bool] = None,
+                api_gateway_props: typing.Any = None,
+                create_request_template: typing.Optional[builtins.str] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                delete_request_template: typing.Optional[builtins.str] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                read_request_template: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
             check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
             check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
